@@ -362,7 +362,9 @@ def test_simple_row_groupby(by, as_index, col1_category):
     eval_general(
         modin_groupby,
         pandas_groupby,
-        lambda df: df.pct_change(),
+        lambda df: df.pct_change(
+            periods=2, fill_method="pad", limit=1, freq=None, axis=1
+        ),
         modin_df_almost_equals_pandas,
         is_default=True,
     )
@@ -1616,9 +1618,9 @@ def test_agg_exceptions(operation):
 
 @pytest.mark.skip(
     "Pandas raises a ValueError on empty dictionary aggregation since 1.2.0"
-    "It's unclear is that was made on purpose or it is a bug. That question"
-    "was asked in https://github.com/pandas-dev/pandas/issues/39609."
-    "So until the answer this test is disabled."
+    + "It's unclear is that was made on purpose or it is a bug. That question"
+    + "was asked in https://github.com/pandas-dev/pandas/issues/39609."
+    + "So until the answer this test is disabled."
 )
 @pytest.mark.parametrize(
     "kwargs",
@@ -1941,7 +1943,7 @@ def test_handle_as_index(
     ):
         pytest.skip(
             "The linked bug makes pandas raise an exception when 'by' is categorical: "
-            "https://github.com/pandas-dev/pandas/issues/36698"
+            + "https://github.com/pandas-dev/pandas/issues/36698"
         )
 
     df = pandas.DataFrame(test_groupby_data)
